@@ -412,6 +412,37 @@ class InfEngineServer:
         else:
             return "NOT RUNNING"
 
+    def clean(self):
+        self._logger.info(f"Cleaning InfServers...")
+
+        config = self._load_config("environment")
+
+        count = self._clean(
+            self.root_path / INF_ENGINE_PATH_ENGINES,
+            self.root_path / INF_ENGINE_LINK_READY,
+            int(config["Clean"]["releases"]),
+        )
+
+        if count:
+            self._logger.info(f"Deleted {count} engines.")
+
+        count = self._clean(
+            self.root_path / INF_ENGINE_PATH_RELEASES,
+            self.root_path / INF_ENGINE_LINK_RELEASE,
+            int(config["Clean"]["releases"]),
+        )
+
+        if count:
+            self._logger.info(f"Deleted {count} releases.")
+
+    def _clean(self, dir: Path, ignore: Path, limit: int = 0) -> int:
+        # TODO
+        pass
+
+    def _clean_multidb(self):
+        # TODO
+        pass
+
     def update_data(
         self,
         dldata: str = None,
